==> dotclear_2.4.2%2bdfsg.orig.tar.gz: dotclear-2.4.2+dfsg/locales/fr/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Aller au contenu';
$GLOBALS['__l10n']['To menu'] = 'Aller au menu';
$GLOBALS['__l10n']['To search'] = 'Aller à la recherche';
$GLOBALS['__l10n']['By'] = 'Par';
$GLOBALS['__l10n']['by'] = 'par';
$GLOBALS['__l10n']['on'] = 'le';
$GLOBALS['__l10n']['On'] = 'Le';
$GLOBALS['__l10n']['Continue reading'] = 'Lire la suite';
$GLOBALS['__l10n']['no comment'] = 'aucun commentaire';
$GLOBALS['__l10n']['one comment'] = 'un commentaire';
$GLOBALS['__l10n']['%d comments'] = '%d commentaires';
$GLOBALS['__l10n']['no trackback'] = 'aucun rétrolien';
$GLOBALS['__l10n']['one trackback'] = 'un rétrolien';
$GLOBALS['__l10n']['%d trackbacks'] = '%d rétroliens';
$GLOBALS['__l10n']['no attachment'] = 'aucune annexe';
$GLOBALS['__l10n']['one attachment'] = 'une annexe';
$GLOBALS['__l10n']['%d attachments'] = '%d annexes';
$GLOBALS['__l10n']['previous entries'] = 'billets précédents';
$GLOBALS['__l10n']['page'] = 'page';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['next entries'] = 'billets suivants';
$GLOBALS['__l10n']['Search'] = 'Recherche';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Votre recherche de <em>%1$s</em> n\'a donné aucun résultat.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Votre recherche de <em>%1$s</em> a donné <strong>%2$s</strong> résultat.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Votre recherche de <em>%1$s</em> a donné <strong>%2$s</strong> résultats.';
$GLOBALS['__l10n']['Home'] = 'Accueil';
$GLOBALS['__l10n']['All keywords'] = 'Tous les mots clés';
$GLOBALS['__l10n']['Best of me'] = 'À retenir';
$GLOBALS['__l10n']['Languages'] = 'Langues';
$GLOBALS['__l10n']['Categories'] = 'Catégories';
$GLOBALS['__l10n']['Subcategories'] = 'Sous-catégories';
$GLOBALS['__l10n']['Archives'] = 'Archives';
$GLOBALS['__l10n']['Links'] = 'Liens';
$GLOBALS['__l10n']['Subscribe'] = 'S\'abonner';
$GLOBALS['__l10n']['Entries feed'] = 'Fil des billets';
$GLOBALS['__l10n']['Comments feed'] = 'Fil des commentaires';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Fil Atom des commentaires de ce blog';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Fil Atom des billets de cette catégorie';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Fil Atom des commentaires de cette catégorie';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Fil des commentaires de ce billet';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Fil Atom des commentaires de ce billet';
$GLOBALS['__l10n']['Attachments'] = 'Annexes';
$GLOBALS['__l10n']['Permalink'] = 'Lien permanent';
$GLOBALS['__l10n']['Comments'] = 'Commentaires';
$GLOBALS['__l10n']['Your comment'] = 'Votre commentaire';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Votre commentaire a été publié.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Votre commentaire a été enregistré et sera publié après validation.';
$GLOBALS['__l10n']['Add a comment'] = 'Ajouter un commentaire';
$GLOBALS['__l10n']['Name or nickname'] = 'Nom ou pseudo';
$GLOBALS['__l10n']['Email address'] = 'Adresse email';
$GLOBALS['__l10n']['Website'] = 'Site web';
$GLOBALS['__l10n']['optional'] = 'facultatif';
$GLOBALS['__l10n']['Comment'] = 'Commentaire';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = 'Les commentaires peuvent être formatés en utilisant une syntaxe wiki simplifiée.';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'Le code HTML est affiché comme du texte et les adresses web sont automatiquement transformées.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Se souvenir de moi sur ce blog';
$GLOBALS['__l10n']['preview'] = 'prévisualiser';
$GLOBALS['__l10n']['send'] = 'envoyer';
$GLOBALS['__l10n']['They posted on the same topic'] = 'La discussion continue ailleurs';
$GLOBALS['__l10n']['Trackback URL'] = 'URL de rétrolien';
$GLOBALS['__l10n']['You must provide an author name'] = 'Vous devez indiquer un nom';
$GLOBALS['__l10n']['You must provide a comment'] = 'Vous devez écrire un commentaire';
$GLOBALS['__l10n']['Email address is not valid'] = 'Adresse email incorrecte';
$GLOBALS['__l10n']['Document not found'] = 'Document non trouvé';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Le document que vous cherchez n\'existe pas.';
$GLOBALS['__l10n']['Powered by %s'] = 'Propulsé par %s';
$GLOBALS['__l10n']['Subscribe to'] = 'S\'abonner à';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Qu\'est ce qu\'un fil RSS ?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Un fil RSS recueille les informations de mise à jour d\'un site. Il fournit le contenu des billets ou des commentaires ou un extrait de ceux-ci, ainsi qu\'un lien vers les versions complètes et quelques autres informations. Ce fil a pour vocation d\'être lu par un <a href="http://fr.wikipedia.org/wiki/Agr%C3%A9gateur">agrégateur</a> RSS.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Copier simplement l\'adresse suivante dans votre agrégateur :';
$GLOBALS['__l10n']['Password needed'] = 'Mot de passe nécessaire';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Vous devez indiquer un mot de passe pour accéder à cette partie.';
$GLOBALS['__l10n']['Password:'] = 'Mot de passe :';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Vous devez indiquer une adresse e-mail valide.';
$GLOBALS['__l10n']['Read'] = 'Lire';
?>

==> dotclear_2.7.5%2bdfsg.orig.tar.gz: dotclear-2.7.5+dfsg/locales/fr/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Aller au contenu';
$GLOBALS['__l10n']['To menu'] = 'Aller au menu';
$GLOBALS['__l10n']['To search'] = 'Aller à la recherche';
$GLOBALS['__l10n']['By'] = 'Par';
$GLOBALS['__l10n']['by'] = 'par';
$GLOBALS['__l10n']['on'] = 'le';
$GLOBALS['__l10n']['On'] = 'Le';
$GLOBALS['__l10n']['Continue reading'] = 'Lire la suite';
$GLOBALS['__l10n']['no comments'] = 'aucun commentaire';
$GLOBALS['__l10n']['one comment'] = 'un commentaire';
$GLOBALS['__l10n']['%d comments'] = '%d commentaires';
$GLOBALS['__l10n']['no trackbacks'] = 'aucun rétrolien';
$GLOBALS['__l10n']['one trackback'] = 'un rétrolien';
$GLOBALS['__l10n']['%d trackbacks'] = '%d rétroliens';
$GLOBALS['__l10n']['no attachments'] = 'aucune annexe';
$GLOBALS['__l10n']['one attachment'] = 'une annexe';
$GLOBALS['__l10n']['%d attachments'] = '%d annexes';
$GLOBALS['__l10n']['previous entries'] = 'billets précédents';
$GLOBALS['__l10n']['page'] = 'page';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['next entries'] = 'billets suivants';
$GLOBALS['__l10n']['Search'] = 'Recherche';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Votre recherche de <em>%1$s</em> n\'a donné aucun résultat.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Votre recherche de <em>%1$s</em> a donné <strong>%2$s</strong> résultat.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Votre recherche de <em>%1$s</em> a donné <strong>%2$s</strong> résultats.';
$GLOBALS['__l10n']['Home'] = 'Accueil';
$GLOBALS['__l10n']['All keywords'] = 'Tous les mots clés';
$GLOBALS['__l10n']['Best of me'] = 'À retenir';
$GLOBALS['__l10n']['Languages'] = 'Langues';
$GLOBALS['__l10n']['Categories'] = 'Catégories';
$GLOBALS['__l10n']['Subcategories'] = 'Sous-catégories';
$GLOBALS['__l10n']['Archives'] = 'Archives';
$GLOBALS['__l10n']['Links'] = 'Liens';
$GLOBALS['__l10n']['Subscribe'] = 'S\'abonner';
$GLOBALS['__l10n']['Entries feed'] = 'Fil des billets';
$GLOBALS['__l10n']['Comments feed'] = 'Fil des commentaires';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Fil Atom des commentaires de ce blog';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Fil Atom des billets de cette catégorie';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Fil Atom des commentaires de cette catégorie';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Fil des commentaires de ce billet';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Fil Atom des commentaires de ce billet';
$GLOBALS['__l10n']['Attachments'] = 'Annexes';
$GLOBALS['__l10n']['Permalink'] = 'Lien permanent';
$GLOBALS['__l10n']['Comments'] = 'Commentaires';
$GLOBALS['__l10n']['Your comment'] = 'Votre commentaire';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Votre commentaire a été publié.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Votre commentaire a été enregistré et sera publié après validation.';
$GLOBALS['__l10n']['Add a comment'] = 'Ajouter un commentaire';
$GLOBALS['__l10n']['Name or nickname'] = 'Nom ou pseudo';
$GLOBALS['__l10n']['Email address'] = 'Adresse email';
$GLOBALS['__l10n']['Website'] = 'Site web';
$GLOBALS['__l10n']['optional'] = 'facultatif';
$GLOBALS['__l10n']['Comment'] = 'Commentaire';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = 'Les commentaires peuvent être formatés en utilisant une syntaxe wiki simplifiée.';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'Le code HTML est affiché comme du texte et les adresses web sont automatiquement transformées.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Se souvenir de moi sur ce blog';
$GLOBALS['__l10n']['preview'] = 'prévisualiser';
$GLOBALS['__l10n']['send'] = 'envoyer';
$GLOBALS['__l10n']['They posted on the same topic'] = 'La discussion continue ailleurs';
$GLOBALS['__l10n']['Trackback URL'] = 'URL de rétrolien';
$GLOBALS['__l10n']['You must provide an author name'] = 'Vous devez indiquer un nom';
$GLOBALS['__l10n']['You must provide a comment'] = 'Vous devez écrire un commentaire';
$GLOBALS['__l10n']['Email address is not valid'] = 'Adresse email incorrecte';
$GLOBALS['__l10n']['Document not found'] = 'Document non trouvé';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Le document que vous cherchez n\'existe pas.';
$GLOBALS['__l10n']['Powered by %s'] = 'Propulsé par %s';
$GLOBALS['__l10n']['Subscribe to'] = 'S\'abonner à';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Qu\'est ce qu\'un fil RSS ?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Un fil RSS recueille les informations de mise à jour d\'un site. Il fournit le contenu des billets ou des commentaires ou un extrait de ceux-ci, ainsi qu\'un lien vers les versions complètes et quelques autres informations. Ce fil a pour vocation d\'être lu par un <a href="http://fr.wikipedia.org/wiki/Agr%C3%A9gateur">agrégateur</a> RSS.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Copier simplement l\'adresse suivante dans votre agrégateur :';
$GLOBALS['__l10n']['Password needed'] = 'Mot de passe nécessaire';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Vous devez indiquer un mot de passe pour accéder à cette partie.';
$GLOBALS['__l10n']['Password:'] = 'Mot de passe :';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Vous devez indiquer une adresse e-mail valide.';
$GLOBALS['__l10n']['Read'] = 'Lire';
